==> dojo-1.9.4.tgz: package/cldr/nls/zh/coptic.js <==
define(
//begin v1.x content
{
	"field-second": "秒钟",
	"field-year-relative+-1": "去年",
	"field-week": "周",
	"field-month-relative+-1": "上个月",
	"field-day-relative+-1": "昨天",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-day-relative+-2": "前天",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"field-year": "年",
	"field-week-relative+0": "本周",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"field-week-relative+1": "下周",
	"field-minute": "分钟",
	"field-week-relative+-1": "上周",
	"field-day-relative+0": "今天",
	"field-hour": "小时",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "后天",
	"field-day": "日",
	"field-month-relative+0": "本月",
	"field-month-relative+1": "下个月",
	"field-dayperiod": "上午/下午",
	"field-month": "月",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"field-era": "时期",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"field-weekday": "星期",
	"field-zone": "时区"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/zh/coptic.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "本周六",
	"field-sat-relative+1": "下周六",
	"field-dayperiod": "上午/下午",
	"field-sun-relative+-1": "上周日",
	"field-mon-relative+-1": "上周一",
	"field-minute": "分钟",
	"field-day-relative+-1": "昨天",
	"field-weekday": "工作日",
	"field-day-relative+-2": "前天",
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-era": "纪元",
	"field-hour": "小时",
	"field-sun-relative+0": "本周日",
	"field-sun-relative+1": "下周日",
	"months-standAlone-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"field-wed-relative+-1": "上周三",
	"field-day-relative+0": "今天",
	"field-day-relative+1": "明天",
	"field-day-relative+2": "后天",
	"field-tue-relative+0": "本周二",
	"field-zone": "时区",
	"field-tue-relative+1": "下周二",
	"field-week-relative+-1": "上周",
	"field-year-relative+0": "今年",
	"field-year-relative+1": "明年",
	"field-sat-relative+-1": "上周六",
	"field-year-relative+-1": "去年",
	"field-year": "年",
	"field-fri-relative+0": "本周五",
	"field-fri-relative+1": "下周五",
	"months-standAlone-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"field-week": "周",
	"field-week-relative+0": "本周",
	"field-week-relative+1": "下周",
	"months-format-abbr": [
		"1月",
		"2月",
		"3月",
		"4月",
		"5月",
		"6月",
		"7月",
		"8月",
		"9月",
		"10月",
		"11月",
		"12月",
		"13月"
	],
	"field-month-relative+0": "本月",
	"field-month": "月",
	"field-month-relative+1": "下个月",
	"field-fri-relative+-1": "上周五",
	"field-second": "秒钟",
	"field-tue-relative+-1": "上周二",
	"field-day": "日",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-mon-relative+0": "本周一",
	"field-mon-relative+1": "下周一",
	"field-thu-relative+0": "本周四",
	"field-second-relative+0": "现在",
	"field-thu-relative+1": "下周四",
	"months-format-wide": [
		"一月",
		"二月",
		"三月",
		"四月",
		"五月",
		"六月",
		"七月",
		"八月",
		"九月",
		"十月",
		"十一月",
		"十二月",
		"十三月"
	],
	"field-wed-relative+0": "本周三",
	"field-wed-relative+1": "下周三",
	"field-month-relative+-1": "上个月",
	"field-thu-relative+-1": "上周四"
}
//end v1.x content
);
